@@ -3,21 +3,18 @@ import sys
 help_message = '''
 python3 -m pip install cameo_claw --upgrade
 python3 -c "
-from cameo_claw import it_filter
+from cameo_claw import it_filter_group
 lst_url=[
 'https://cameo-claw-data.vercel.app/device_21152332479_daily_2022-03-30.csv',
 'https://cameo-claw-data.vercel.app/device_21152332479_daily_2022-03-31.csv']
+target_directory = './data/topic_filter_group/'
 int_total=len(lst_url)
-target_directory = './data/topic_filter/'
 lst_distinct_column = ['deviceId', 'localTime', 'sensorId']
-lst_column_match=[
-    ['sensorId','pm2_5'],
-    ['sensorId','voc']
-]
-sort_column='localTime'
-for int_progress, done_url in it_filter(lst_url, target_directory, lst_distinct_column, lst_column_match, sort_column):
-    print(f'int_progress/int_total = {int_progress}/{int_total}')
-    print(f'done url: {done_url}')
+lst_column_match = [['sensorId', 'pm2_5'], ['sensorId', 'voc']]
+sort_column = 'localTime'
+lst_group_by_column = ['deviceId']
+for int_progress, done_url in it_filter_group(lst_url, target_directory, lst_distinct_column, lst_column_match, sort_column, lst_group_by_column):
+        pass
 "
 '''
 
