@@ -1,5 +1,4 @@
 import gzip
-import multiprocessing
 from hashlib import md5
 from io import BytesIO
 
@@ -8,7 +7,7 @@ from fastapi import FastAPI
 import uvicorn
 from fastapi.middleware.cors import CORSMiddleware
 from fastapi.responses import StreamingResponse
-from cameo_claw.cameo_claw import it_chunk_pd, it_chunk_pl
+from cameo_claw.cameo_claw import it_chunk_pl
 
 from pydantic import BaseModel
 
@@ -35,19 +34,6 @@ class ItemUrlFilter(BaseModel):
     sort_column: str = 'localTime'
 
 
-def it_streaming_pd(i: ItemUrlFilter):
-    try:
-        yield write_csv_header_to_gz_pd(i)
-        for int_progress, bytes1 in it_chunk_pd(
-                i.lst_url, i.target_directory, i.lst_distinct_column, i.lst_column_match, i.sort_column):
-            if bytes1:
-                yield bytes1
-            else:
-                continue
-    except Exception as e:
-        print('it_streaming_pd,exception:', e)
-
-
 def it_streaming_pl(i: ItemUrlFilter):
     try:
         yield write_csv_header_to_gz_pl(i)
@@ -88,17 +74,11 @@ def streaming_post(i: ItemUrlFilter):
     return md5_hex
 
 
-@app.get("/api/streaming_get_pd/")
-def streaming_get_pd(md5_hex):
-    dic = {'content-disposition': f"attachment; filename*=utf-8''all.csv.gz"}
-    return StreamingResponse(it_streaming_pd(dic_item_url_filter[md5_hex]), headers=dic)
-
-
 @app.get("/api/streaming_get_pl/")
 def streaming_get_pl(md5_hex):
     dic = {'content-disposition': f"attachment; filename*=utf-8''all.csv.gz"}
     return StreamingResponse(it_streaming_pl(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20449):
+def server(host='0.0.0.0', int_port=20412):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
