@@ -1,7 +1,7 @@
 import requests
 
 from cameo_claw import it_distinct, it_group, it_filter, server, it_filter_group, it_streaming_pl, it_download, \
-    it_filter_group_mean_count
+    it_filter_group_mean_count, it_filter_group_concat
 import time
 from cameo_claw.log import log
 
@@ -270,6 +270,18 @@ def test_it_filter_group():
         pass
 
 
+def test_it_filter_group_concat():
+    target_directory = './data/topic_filter_group_concat/'
+    int_total, lst_distinct_column = total_distinct()
+    lst_column_match = [['sensorId', 'pm2_5'], ['sensorId', 'voc']]
+    sort_column = 'localTime'
+    lst_group_by_column = ['deviceId']
+    for int_progress, done_url in it_filter_group_concat(
+            get_lst_url_taipei_100(), target_directory, lst_distinct_column,
+            lst_column_match, sort_column, lst_group_by_column):
+        pass
+
+
 def test_it_filter_group_mean_count():
     target_directory = './data/topic_filter_group_mean_count/'
     int_total, lst_distinct_column = total_distinct()
@@ -292,14 +304,14 @@ if __name__ == '__main__':
     #     test_server()
     # if sys.argv[1] == 'client':
     #     test_client()
-    # if sys.argv[1] == 'filter':
-    #     t = time.time()
-    #     test_it_filter()
-    #     log(f'test_it_filter:{time.time() - t}')
 
     # t = time.time()
-    # test_it_download()
-    # log(f'test_it_download:{time.time() - t}')
+    # test_it_filter()
+    # log(f'test_it_filter:{time.time() - t}')
+
+    t = time.time()
+    test_it_download()
+    log(f'test_it_download:{time.time() - t}')
 
     # t = time.time()
     # test_it_distinct()
@@ -309,12 +321,17 @@ if __name__ == '__main__':
     # test_it_group()
     # log(f'test_it_group:{time.time() - t}')
 
-    t = time.time()
-    test_it_filter_group()
-    log(f'test_it_group:{time.time() - t}')
+    # t = time.time()
+    # test_it_filter_group()
+    # log(f'test_it_group:{time.time() - t}')
+
+    # t = time.time()
+    # test_it_filter_group_concat()
+    # log(f'test_it_group:{time.time() - t}')
 
     # t = time.time()
     # test_it_filter_group_mean_count()
     # log(f'test_it_group:{time.time() - t}')
 
 # sh/go.sh
+
